@@ -295,7 +295,7 @@ C<>SOAP::Transport::HTTP::Client::get_basic_credentials>:
   __PACKAGE__->init ( {
       localStorage        => "Cache::FileCache",
       localStorageOptions => {
-                'namespace'          => 'MyNamespace',
+                'namespace'          => 'lemonldap-ng',
                 'default_expires_in' => 600,
       },
       configStorage       => {
@@ -323,7 +323,7 @@ set environment variables.
   __PACKAGE__->init ( {
       localStorage        => "Cache::FileCache",
       localStorageOptions => {
-                'namespace'          => 'MyNamespace',
+                'namespace'          => 'lemonldap-ng',
                 'default_expires_in' => 600,
       },
       configStorage       => {
